#
# spec file for package python-sphinx-gallery
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%{?sle15_python_module_pythons}
Name:           python-sphinx-gallery
Version:        0.17.1
Release:        2.1
Summary:        Sphinx extension that builds an HTML gallery of examples
License:        BSD-3-Clause
URL:            https://github.com/sphinx-gallery/sphinx-gallery
Source:         https://files.pythonhosted.org/packages/source/s/sphinx-gallery/sphinx_gallery-%{version}.tar.gz
BuildRequires:  %{python_module pip}
BuildRequires:  %{python_module setuptools_scm}
BuildRequires:  %{python_module wheel}
BuildRequires:  python-rpm-macros
# SECTION test requirements
BuildRequires:  %{python_module Pillow}
BuildRequires:  %{python_module Sphinx >= 4}
BuildRequires:  %{python_module dbm}
BuildRequires:  %{python_module lxml}
BuildRequires:  %{python_module matplotlib}
BuildRequires:  %{python_module numpy}
BuildRequires:  %{python_module pytest-cov}
BuildRequires:  %{python_module pytest}
# /SECTION
BuildRequires:  fdupes
Requires:       python-Pillow
Requires:       python-Sphinx >= 4
Suggests:       python-numpy
Suggests:       python-graphviz
Requires(post): update-alternatives
Requires(postun): update-alternatives
BuildArch:      noarch
%python_subpackages

%description
A Sphinx extension that builds an HTML gallery of examples from any set of Python scripts.

%prep
%autosetup -p1 -n sphinx_gallery-%{version}

%build
%pyproject_wheel

%install
%pyproject_install
# Don't ship tests
%python_expand rm -r %{buildroot}%{$python_sitelib}/sphinx_gallery/tests
%python_clone -a %{buildroot}%{_bindir}/sphinx_gallery_py2jupyter
%python_expand %fdupes %{buildroot}%{$python_sitelib}

%check
# Requires network
donttest="test_embed_code_links_get_data"
# Requires jupyterlite_sphinx, long dependency chain and we don't ship it
donttest+=" or test_dummy_image"
%pytest sphinx_gallery/tests -k "not ($donttest)"

%post
%python_install_alternative sphinx_gallery_py2jupyter

%postun
%python_uninstall_alternative sphinx_gallery_py2jupyter

%files %{python_files}
%python_alternative %{_bindir}/sphinx_gallery_py2jupyter
%{python_sitelib}/sphinx_gallery
%{python_sitelib}/sphinx_gallery-%{version}.dist-info

%changelog
* Wed Sep 25 2024 ecsos <ecsos@opensuse.org>
- Add %%{?sle15_python_module_pythons}
* Sun Sep  8 2024 Dirk Müller <dmueller@suse.com>
- update to 0.17.1:
  * FIX: Fix stability of stored compiled regex #1369 (larsoner)
  * ENH: Improve _sanitize_rst #1366 (timhoffm)
  * Obey prefer_full_module setting when finding backreferences
    [#1364] (QuLogic)
  * Fix linking to class attributes with prefer_full_module #1363
    (QuLogic)
  * Improve minigallery directive path input resolution #1360
    (lucyleeow)
  * FIX Allow str path minigallery entries when backreferences
    off #1355 (lucyleeow)
  * FIX generate zipfiles when index passed by user #1353
    (lucyleeow)
  * DOC Improve doc about joblib warnings #1367 (lucyleeow)
  * DOC add note on filtering joblib warnings #1362 (lucyleeow)
  * DOC Minor update to minigallery directive doc #1358
    (lucyleeow)
  * MNT Change mark and fixture names for adding files #1365
    (lucyleeow)
  * MNT Add warning when ‘examples_dirs’ and ‘gallery_dirs’
    unequal lengths #1361 (lucyleeow)
  * Update pyvista in doc CI #1352 (lucyleeow)
  * MNT Bump version #1350 (lucyleeow)
  * Introduction tooltip corresponds to the first paragraph #1344
    (fgmacedo)
  * FIX Jupyterlite in CircleCI artifact #1336 (lesteve)
  * MNT: Rename README.rst to GALLERY_HEADER.rst #1321 (timhoffm)
  * [ENH] Add custom thumbnails for failing examples #1313
    (tsbinns)
  * ENH integrate download/launcher links into pydata-sphinx-
    theme secondary sidebar #1312 (Charlie-XIAO)
  * add option for zip downloads #1299 (jamiecook)
  * Allow setting animation format from gallery config #1243
    (QuLogic)
  * Fix handling of multi-module intersphinx registries #1320
    (QuLogic)
  * BUG: Fix bug with traceback with SyntaxError #1301 (larsoner)
  * DOC Add napari to users #1346 (lucyleeow)
  * DOC Fix nested_sections #1339 (lucyleeow)
  * DOC Improve nested_sections #1326 (lucyleeow)
  * DOC: Remove definition lists from contribution guide #1318
    (QuLogic)
  * MNT: fixed documentation links in the readme #1310 (story645)
  * MNT: Fix gallery_conf changes do not need to be returned
    [#1347] (lucyleeow)
  * MNT: Sort imports and add to pre commit #1337 (lucyleeow)
  * MNT: Refactor generate_file_rst #1335 (lucyleeow)
  * MNT: Refactor _fill_gallery_conf_defaults #1334 (lucyleeow)
  * MNT Use os.sep everywhere #1333 (lucyleeow)
  * MNT: Refactor generate_dir_rst and generate_gallery_rst #1332
    (lucyleeow)
  * MNT: Add ipython to dev dependencies #1329 (lucyleeow)
  * Fix make file clean in tinybuild #1327 (lucyleeow)
  * Bump the actions group with 5 updates #1325 (dependabot[bot])
  * Include dev dependencies in pyproject.toml and update docs on
    requirements #1317 (AlexSzatmary)
  * MNT: Turn the block tuple into a namedtuple #1303 (timhoffm)
  * lint: define codespell in pyproject.toml #1298 (Borda)
  * MAINT Bump version 0.17 #1297 (lucyleeow)
* Tue May 21 2024 Steve Kowalik <steven.kowalik@suse.com>
- Initial release of 0.16.0
